# e621
e621 is a low-level e621.net API wrapper written for Python.

# Requirements
+ Python 3.6
+ requests
+ json

# Installation

## From master branch
```bash
$ git clone https://github.com/PatriotRossii/e621-py.git 
$ pip install -e e621-py
``` 

## From PyPi
```bash
$ pip install e621
```
